==> seam-persistence-3.0.0.Final-sources.jar: org/jboss/seam/persistence/util/EnvironmentUtils.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.seam.persistence.util;


/**
 * Provides information about the runtime environment
 * 
 * @author Stuart Douglas
 * 
 */
public final class EnvironmentUtils
{
  public static boolean isEEEnvironment()
  {
     boolean eeEnv = true;
     try
     {
        if (Thread.currentThread().getContextClassLoader() != null)
        {
           Thread.currentThread().getContextClassLoader().loadClass("javax.ejb.Stateless");
        }
        else
        {
           Class.forName("javax.ejb.Stateless");
        }
     }
     catch (ClassNotFoundException e)
     {
        eeEnv = false;
     }
     catch (NoClassDefFoundError e)
     {
        eeEnv = false;
     }
     return eeEnv;
  }
}

==> seam-persistence-3.1.0.Final-sources.jar: org/jboss/seam/persistence/util/EnvironmentUtils.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.seam.persistence.util;


/**
 * Provides information about the runtime environment
 *
 * @author Stuart Douglas
 */
public final class EnvironmentUtils {
    public static boolean isEEEnvironment() {
        boolean eeEnv = true;
        try {
            if (Thread.currentThread().getContextClassLoader() != null) {
                Thread.currentThread().getContextClassLoader().loadClass("javax.ejb.Stateless");
            } else {
                Class.forName("javax.ejb.Stateless");
            }
        } catch (ClassNotFoundException e) {
            eeEnv = false;
        } catch (NoClassDefFoundError e) {
            eeEnv = false;
        }
        return eeEnv;
    }
}
